==> mc-4.1.tar.gz: mc-4.1/tk/gui.mfind.tcl <==
set props(.mfind.columns) 7
set props(.mfind.rows)    10
set props(.mfind.frames)  2
set props(.mfind.texts)   0
set props(.mfind.components)   "label-search button-chdir button-again start-stop button-quit button-view button-panelize listbox "
set props(.mfind.count)   8
set props(.mfind.props.label-search) "-in .mfind.widgets -column 5 -row 7 -columnspan 9 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky w"
set props(.mfind.props.button-chdir) "-in .mfind.widgets -column 5 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky ew"
set props(.mfind.props.button-again) "-in .mfind.widgets -column 7 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky ew"
set props(.mfind.props.start-stop) "-in .mfind.widgets -column 9 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-quit) "-in .mfind.widgets -column 11 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-view) "-in .mfind.widgets -column 5 -row 17 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-panelize) "-in .mfind.widgets -column 7 -row 17 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.listbox) "-in .mfind.widgets -column 3 -row 3 -columnspan 13 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.frame0) "-in .mfind.widgets -column 3 -row 13 -columnspan 13 -rowspan 7 -ipadx 0 -ipady 0 -padx 2 -pady 2 -sticky nesw"
set props(.mfind.relief.frame0) groove
set props(.mfind.frame1) "-in .mfind.widgets -column 3 -row 5 -columnspan 13 -rowspan 5 -ipadx 0 -ipady 0 -padx 2 -pady 2 -sticky nesw"
set props(.mfind.relief.frame1) groove

==> mc-4.1.35.tar.gz: mc-4.1.35/tk/gui.mfind.tcl <==
set props(.mfind.columns) 7
set props(.mfind.rows)    10
set props(.mfind.frames)  2
set props(.mfind.texts)   0
set props(.mfind.components)   "label-search button-chdir button-again start-stop button-quit button-view button-edit button-panelize listbox "
set props(.mfind.count)   9
set props(.mfind.props.label-search) "-in .mfind.widgets -column 5 -row 7 -columnspan 9 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky w"
set props(.mfind.props.button-chdir) "-in .mfind.widgets -column 5 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky ew"
set props(.mfind.props.button-again) "-in .mfind.widgets -column 7 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky ew"
set props(.mfind.props.start-stop) "-in .mfind.widgets -column 9 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-quit) "-in .mfind.widgets -column 11 -row 15 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-view) "-in .mfind.widgets -column 7 -row 17 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-edit) "-in .mfind.widgets -column 9 -row 17 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.button-panelize) "-in .mfind.widgets -column 5 -row 17 -columnspan 1 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.props.listbox) "-in .mfind.widgets -column 3 -row 3 -columnspan 13 -rowspan 1 -ipadx 0 -ipady 0 -padx 0 -pady 0 -sticky {}"
set props(.mfind.frame0) "-in .mfind.widgets -column 3 -row 13 -columnspan 13 -rowspan 7 -ipadx 0 -ipady 0 -padx 2 -pady 2 -sticky nesw"
set props(.mfind.relief.frame0) groove
set props(.mfind.frame1) "-in .mfind.widgets -column 3 -row 5 -columnspan 13 -rowspan 5 -ipadx 0 -ipady 0 -padx 2 -pady 2 -sticky nesw"
set props(.mfind.relief.frame1) groove
